@@ -318,7 +318,7 @@ class OVSDBData(object):
         return agent_l2_pop_enabled
 
     def _handle_l2pop(self, context, new_remote_macs):
-        """handle vxlan tunnel creation based on whether l2pop is enabled or not.
+        """handle vxlan tunnel creation based on l2pop is enabled or not.
 
         if l2pop is enabled in L2 agent on a host to which port belongs, then
         call add_fdb_entries. otherwise, call tunnel_sync.
